netapp_ontap.models.nfs_service_protocol API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_protocol`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceProtocolSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceProtocol object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `v3_64bit_identifiers_enabled: bool GET POST PATCH`

    Specifies whether 64-bit support for NFSv3 FSIDs and file IDs is enabled.

  `v3_enabled: bool GET POST PATCH`

    Specifies whether NFSv3 protocol is enabled.

  `v3_features: NfsServiceProtocolV3Features GET POST PATCH`

    The v3_features field of the nfs_service_protocol.

  `v40_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.0 protocol is enabled.

  `v40_features: NfsServiceProtocolV40Features GET POST PATCH`

    The v40_features field of the nfs_service_protocol.

  `v41_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later protocol is enabled.

  `v41_features: NfsServiceProtocolV41Features GET POST PATCH`

    The v41_features field of the nfs_service_protocol.

  `v42_features: NfsServiceProtocolV42Features GET POST PATCH`

    The v42_features field of the nfs_service_protocol.

  `v4_64bit_identifiers_enabled: bool GET POST PATCH`

    Specifies whether 64-bit support for NFSv4.x FSIDs and file IDs is enabled.

  `v4_fsid_change: bool GET POST PATCH`

    Specifies whether the change in FSID when NFSv4 clients traverse file systems is displayed.

  `v4_grace_seconds: Size GET POST PATCH`

    Specifies the grace period for clients to reclaim file locks after a server failure.

  `v4_id_domain: str GET POST PATCH`

    Specifies the domain portion of the string form of user and group names as defined by the NFSv4 protocol.

  `v4_lease_seconds: Size GET POST PATCH`

    Specifies the lease seconds of the NFSv4 clients. If it is inactive for more than the time displayed, all of the file lock states on a node might be lost.

  `v4_session_slot_reply_cache_size: Size GET POST PATCH`

    Specifies the number of bytes of the reply that is cached in each NFSv4.x session slot.

  `v4_session_slots: Size GET POST PATCH`

    Specifies the number of entries in NFSv4.x session slot table.

  `v4_subnet_filter_enabled: bool GET POST PATCH`

    Specifies whether NFSv4 subnet filtering is enabled.